THLanguageItem class

Available extensions

Constructors

THLanguageItem({required String direction, required String code, required String name})
const
THLanguageItem.fromJson(Map<String, dynamic> json)
factory

Properties

code String
final
direction String
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textDirection TextDirection

Available on THLanguageItem, provided by the THLanguageItemTranslate extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override