Translation class
Constructors
-
Translation({required List<
THLanguageItem> languages, required Map<String, Map< translationsByCode})String, String> > -
const
-
Translation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languages
→ List<
THLanguageItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translationsByCode
→ Map<
String, Map< String, String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryFromJson(
Map< String, dynamic> json) → Translation?